#!/bin/sh
#
# script for build AIX Samba package
# This script is based on makepkg.sh from Solaris
#

SBINPROGS="smbd nmbd winbindd swat"
BINPROGS="findsmb nmblookup pdbedit rpcclient smbclient smbcquotas smbspool smbtar tdbbackup testparm testidmap wbinfo net ntlm_auth profiles smbcacls smbcontrol smbpasswd smbstatus smbtree tdbdump"
MSGFILES="de.msg en.msg fi.msg fr.msg it.msg ja.msg nl.msg pl.msg tr.msg"
VFSLIBS="audit.so default_quota.so extd_audit.so full_audit.so readonly.so shadow_copy.so cap.so expand_msdfs.so fake_perms.so netatalk.so recycle.so"
DATFILES="lowcase.dat upcase.dat valid.dat"
CHARSETLIBS="CP437.so CP850.so"
AUTHLIBS="script.so"

CONFIGFILES="smb.conf.default"

add_dynamic_entries() 
{
    INDENT="    "
    PREFIX=$INSTALL_BASE

	# Add the binaries, docs and SWAT files
	cd $TMPINSTALLDIR/$INSTALL_BASE

	# Server Binaries
 	for file in $SBINPROGS; do
        echo "$INDENT$PREFIX/sbin/$file"    
	done

	# User Binaries
 	for file in $BINPROGS; do
        echo "$INDENT$PREFIX/bin/$file"
	done
	
	# Libraries
 	for file in $MSGFILES; do
        echo "$INDENT$PREFIX/lib/$file"
	done
 	for file in $DATFILES; do
        echo "$INDENT$PREFIX/lib/$file"
	done
 	for file in $VFSLIBS; do
        echo "$INDENT$PREFIX/lib/vfs/$file"
	done
 	for file in $CHARSETLIBS; do
        echo "$INDENT$PREFIX/lib/charset/$file"
	done

 	for file in $AUTHLIBS; do
		    echo "$INDENT$PREFIX/lib/auth/$file"
	done

	# idmap modules
	  echo "$INDENT$PREFIX/lib/idmap/cdc.so"

	# libtdb
    echo "$INDENT$PREFIX/lib/libtdb.so"	  
	
	# libsmbclient
    echo "$INDENT$PREFIX/lib/libsmbclient.so"
    echo "$INDENT$PREFIX/include/libsmbclient.h"

	# libmsrpc
	  echo "$INDENT$PREFIX/lib/libmsrpc.so"
	  echo "$INDENT$PREFIX/include/libmsrpc.h"

	if [ -f lib/smbwrapper.so -a -f bin/smbsh ]; then
		# smbwrapper
		echo "$INDENT$PREFIX/lib/smbwrapper.so"
		echo "$INDENT$PREFIX/bin/smbsh"
	fi

    # WINBIND
    echo "$INDENT/usr/lib/security/WINBIND"

    # Configuration files
    echo "$INDENT$CONFIGDIR/$CONFIGFILES"

	# man pages

	# Create directories for man page sections if nonexistent
	cd share/man
	for i in 1 2 3 4 5 6 7 8 9; do
		manpages=`ls man$i 2>/dev/null`
		if [ $? -eq 0 ]; then
			for manpage in $manpages; do
				echo "$INDENT$PREFIX/share/man/man${i}/${manpage}"
			done
		fi
	done
	cd ../../

	# SWAT
	list=`find swat -type f | grep -v /.svn/`
	for file in $list; do
		if [ -f $file ]; then
			echo "$INDENT$PREFIX/$file"
		fi
	done

	# Create entries for docs for the beginner
	for file in docs/*pdf; do
		echo "$INDENT$PREFIX/$file"
	done
}

#####################################################################
## BEGIN MAIN 
#####################################################################

# Try to guess the distribution base..
DISTR_BASE=`dirname \`pwd\` |sed -e 's@/packaging$@@'`
echo "Distribution base:  $DISTR_BASE"

# Set Centrify package output directory
CIMSINSTALLDIR="$CIMS_DEST"
mkdir -p $CIMSINSTALLDIR
TMPINSTALLDIR="$CIMSINSTALLDIR/`basename $DISTR_BASE`-build"
echo "Temp install dir:   $TMPINSTALLDIR"
echo "Install directory:  $INSTALL_BASE"

# Figure out Centrify version and build number.
UNDOTTED_VERSION_NUMBER=`echo "$CENTRIFY_VERSION_NUMBER" | sed -e '/\./s/\.//g'`
SAMBA_TRUNCATED_VERSION=`echo "$SAMBA_VERSION" | awk 'BEGIN { FS="."; OFS="." } { print $1, $2 }'`
VERSION=$SAMBA_VERSION-$CENTRIFY_VERSION_NUMBER-$CENTRIFY_BUILD_NUMBER
VRMF_VERSION=$SAMBA_TRUNCATED_VERSION.$UNDOTTED_VERSION_NUMBER.$CENTRIFY_BUILD_NUMBER
##
## first build the source
##

cd $DISTR_BASE/source

if [ "x$1" != "xnobuild" ]; then
    # Make sure libtdb.h exists in the samba source/include; otherwise make install will fail.
    if [ \! -f ./include/libtdb.h ]; then
        cd include
        ln -s  ../tdb/common/libtdb.h .
        cd ..
    fi
    
    # make sure version.h is recreated
    if [ -f ./include/version.h ]; then
        rm -f ./include/version.h
    fi
    sh script/mkversion.sh VERSION include/version.h `pwd`/
    
	CFLAGS="$CFLAGS" \
	LDFLAGS="$LDFLAGS" \
    ./configure  ${CFG_FLAGS} \
        && make clean && make

	if [ $? -ne 0 ]; then
		echo "Build failed!  Exiting...."
		exit 1
	fi
fi

## create temporary install directory, remove it if already exists.
if [ -x $TMPINSTALLDIR ]; then
    sudo rm -rf $TMPINSTALLDIR
fi
mkdir $TMPINSTALLDIR
make DESTDIR=$TMPINSTALLDIR install
make DESTDIR=$TMPINSTALLDIR installclientlib
##
## Now get the install locations
##
SBINDIR=`bin/smbd -b | grep SBINDIR | awk '{print $2}'`
BINDIR=`bin/smbd -b | grep BINDIR | grep -v SBINDIR |  awk '{print $2}'`
SWATDIR=`bin/smbd -b | grep SWATDIR | awk '{print $2}'`
CONFIGFILE=`bin/smbd -b | grep CONFIGFILE | awk '{print $2}'`
LOCKDIR=`bin/smbd -b | grep LOCKDIR | awk '{print $2}'`
CONFIGDIR=`dirname $CONFIGFILE`
LOGFILEBASE=`bin/smbd -b | grep LOGFILEBASE | awk '{print $2}'`
LIBDIR=`bin/smbd -b | grep LIBDIR | awk '{print $2}'`
PIDDIR=`bin/smbd -b | grep PIDDIR | awk '{print $2}'`
PRIVATE_DIR=`bin/smbd -b | grep PRIVATE_DIR | awk '{print $2}'`
DOCDIR=$INSTALL_BASE/docs

## 
## copy some misc files that are not done as part of 'make install'
##
mkdir -p $TMPINSTALLDIR/usr/lib/security
cp -fp nsswitch/WINBIND $TMPINSTALLDIR/usr/lib/security/WINBIND

mkdir -p $TMPINSTALLDIR/$INSTALL_BASE/docs
cp -p ../docs/*pdf $TMPINSTALLDIR/$INSTALL_BASE/docs


cd $DISTR_BASE/packaging/AIX

mkdir -p $TMPINSTALLDIR$CONFIGDIR
cp -p $CONFIGFILES $TMPINSTALLDIR$CONFIGDIR

##
## Main driver 
##

##
## copy over some scripts need for packagaing
##
#mkdir -p $TMPINSTALLDIR/$INSTALL_BASE/scripts
#for i in inetd.conf smb.conf.default services; do
#	cp -fp $i $TMPINSTALLDIR/$INSTALL_BASE/scripts
#done

##
## Start building the template (prototype) file
##
mkdir -p $TMPINSTALLDIR/.info
TEMPLATE=$TMPINSTALLDIR/.info/$CENTRIFY_SAMBA.template
echo "Package Name: CentrifyDC" > $TEMPLATE
echo "Package VRMF: $VRMF_VERSION" >> $TEMPLATE
echo "Update: n" >> $TEMPLATE
echo "Fileset" >> $TEMPLATE
echo "  Fileset Name: CentrifyDC.samba" >> $TEMPLATE
echo "  Fileset VRMF: $VRMF_VERSION" >> $TEMPLATE
echo "  Fileset Description: Centrify Samba SMB client and server" >> $TEMPLATE
echo "  Bosboot required: n" >> $TEMPLATE
# !!! license? !!!
echo "  License agreement acceptance required: n" >> $TEMPLATE
echo "  Include license files in this package: n" >> $TEMPLATE
echo "  Requisites: *prereq CentrifyDC.core 3.0.0.000" >> $TEMPLATE
echo "  Files" >> $TEMPLATE
# Add the dynamic part to the prototype file
(add_dynamic_entries >> $TEMPLATE)
echo "  EOFiles" >> $TEMPLATE
echo "EOFileset" >> $TEMPLATE

##
## copy packaging files 
##
# !!! need these files? copyright request i.swat r.swat !!!
for i in post_i unpost_i pre_d unpre_i; do
    sed -e "s|__INSTALL_BASE__|$INSTALL_BASE|g" \
        -e "s|__CONFIGDIR__|$CONFIGDIR|g" \
        -e "s|__CONFIGFILE__|$CONFIGFILE|g" \
        -e "s|__PRIVATE_DIR__|$PRIVATE_DIR|g" \
        -e "s|__LOCKDIR__|$LOCKDIR|g" \
        -e "s|__LOGFILEBASE__|$LOGFILEBASE|g" \
        -e "s|__PIDDIR__|$PIDDIR|g" \
        $i > $TMPINSTALLDIR/.info/CentrifyDC.samba.$i
done

##
## set file owner, group and permission modes
##

# The owner, group and permission modes must be carefully set before
# making package,  use root account to do this.
sudo sh <<EOF
cd $TMPINSTALLDIR
chown -R root:system .
chown root:security ./usr/lib/security/WINBIND
chmod 444 ./usr/lib/security/WINBIND
(cd .$CONFIGDIR; chmod 644 $CONFIGFILES)
(cd ./.info; chmod 644 *)
(cd ./.info; chmod 755 CentrifyDC.samba.*)
EOF
if [ $? -ne 0 ]; then
    echo "File preparation failed!  Exiting...."
    exit 1
fi

# Create the package

PKG_FILENAME=centrifydc-samba-$VERSION-aix$OS_REV-$ARCH

sudo /usr/sbin/mkinstallp -d $TMPINSTALLDIR -T $TEMPLATE
sudo gzip -c $TMPINSTALLDIR/tmp/CentrifyDC.$VRMF_VERSION.bff \
     > $CIMSINSTALLDIR/$PKG_FILENAME.bff.gz

echo The samba package is in $CIMSINSTALLDIR
