#!/bin/sh
#
# Copyright (C) Shirish A Kalele 2000
# Copyright (C) Gerald Carter    2004
#
# script for building HPUX Samba package
#


#####################################################################
## BEGIN MAIN 
#####################################################################

# Try to guess the distribution base..
DISTR_BASE=`dirname \`pwd\` |sed -e 's@/packaging$@@'`
echo "Distribution base:  $DISTR_BASE"

# Set Centrify package output directory
CIMSINSTALLDIR="$CIMS_DEST"
mkdir -p $CIMSINSTALLDIR
TMPINSTALLDIR="$CIMSINSTALLDIR/`basename $DISTR_BASE`-build"
echo "Temp install dir:   $TMPINSTALLDIR"
echo "Install directory:  $INSTALL_BASE"

# Figure out Centrify version and build number.
VERSION=$SAMBA_VERSION-$CENTRIFY_VERSION_NUMBER-$CENTRIFY_BUILD_NUMBER

##
## first build the source
##

cd $DISTR_BASE/source

if [ "x$1" != "xnobuild" ]; then
    # Make sure libtdb.h exists in the samba source/include; otherwise make install will fail.
    if [ \! -f ./include/libtdb.h ]; then
        cd include
        ln -s  ../tdb/common/libtdb.h .
        cd ..
    fi
    
    # make sure version.h is recreated
    if [ -f ./include/version.h ]; then
        rm -f ./include/version.h
    fi
    sh script/mkversion.sh VERSION include/version.h `pwd`/
    
	CFLAGS="$CFLAGS " \
	LDFLAGS="$LDFLAGS" \
	./configure  ${CFG_FLAGS} \
	&& make clean && make

	if [ $? -ne 0 ]; then
		echo "Build failed!  Exiting...."
		exit 1
	fi
fi
	
mkdir $TMPINSTALLDIR
make DESTDIR=$TMPINSTALLDIR install-everything

## clear out *.old
find $TMPINSTALLDIR -name \*.old |while read x; do rm -rf "$x"; done
 
## 
## copy some misc files that are not done as part of 'make install'
##
if [ "$ARCH" = "pa" ]; then
    SOEXT=sl
    PSF_MACHINE="9000\/[78]*"
    OS_RELEASE="?.11.[0123]*"
else
    SOEXT=so
    PSF_MACHINE="ia64\*"
    OS_RELEASE="?.11.[0123]*"
fi

LIBDIR=`bin/smbd -b | grep LIBDIR | awk '{print $2}'`
cp -fp nsswitch/libnss_wins.$SOEXT $TMPINSTALLDIR/$LIBDIR/
cp -fp nsswitch/libnss_winbind.$SOEXT $TMPINSTALLDIR/$LIBDIR/.

if [ -f nsswitch/pam_winbind.$SOEXT ]; then
	cp -fp nsswitch/pam_winbind.$SOEXT $TMPINSTALLDIR/$LIBDIR/libpam_winbind.$SOEXT
fi

mkdir -p $TMPINSTALLDIR/sbin/init.d
cp -fp  ./script/init.d/centrifydc-samba.hpux $TMPINSTALLDIR/sbin/init.d/centrifydc-samba
mkdir -p $TMPINSTALLDIR/etc/rc.config.d
cp -fp  ./script/init.d/centrifydc-samba.rc.hpux $TMPINSTALLDIR/etc/rc.config.d/centrifydc-samba.rc

mkdir -p $TMPINSTALLDIR/$INSTALL_BASE/docs
cp -p ../docs/*pdf $TMPINSTALLDIR/$INSTALL_BASE/docs


cd $DISTR_BASE/packaging/HPUX

##
## Main Packaging driver 
##
SAMBA_PKG_SPEC=samba.psf

# Update samba version, library file extension, package installation path, os_release and machine_type
sed -e "s|__VERSION__|$VERSION|g" -e "s|__PACKAGE_INSTALL_PATH__|$TMPINSTALLDIR|g" -e "s|__INSTALL_BASE__|$INSTALL_BASE|g" -e "s|__SOEXT__|$SOEXT|g" -e "s|__OS_RELEASE__|$OS_RELEASE|g" -e "s|__PSF_MACHINE__|$PSF_MACHINE|g" samba-template.psf > $SAMBA_PKG_SPEC

sed -e "s|__BASEDIR__|$INSTALL_BASE|g" samba.init.master > samba.init

##
## copy over some scripts need for packagaing
##
mkdir -p $TMPINSTALLDIR/$INSTALL_BASE/scripts
cp -fp smb.conf.default $TMPINSTALLDIR/$INSTALL_BASE/scripts


##
## Create the package
##
PKG_FILE=centrifydc-$SAMBA_ORG_NAME-$CENTRIFY_VERSION_NUMBER-hp$OS_REV-$ARCH.depot
PKG_FILEZ=centrifydc-$SAMBA_ORG_NAME-$CENTRIFY_VERSION_NUMBER-$CENTRIFY_BUILD_NUMBER-hp$OS_REV-$ARCH.depot.gz

echo Making package file $PKG_FILE
sudo /usr/sbin/swpackage -v -s ${SAMBA_PKG_SPEC} -d ${CIMSINSTALLDIR}/${PKG_FILE} \
                       -x target_type=tape -x follow_symlinks=true \*

if [ $? = 0 ]; then
    gzip -c $CIMSINSTALLDIR/$PKG_FILE > $CIMSINSTALLDIR/$PKG_FILEZ
fi
    
echo The samba package is in $CIMSINSTALLDIR
