#!/bin/sh
# Copyright (C) John H Terpstra 1998-2002
# Updated for RPM 3 by Jochen Wiedmann, joe@ispsoft.de
# Changed for a generic tar file rebuild by abartlet@pcug.org.au
# Changed by John H Terpstra to build on RH7.2 - should also work for earlier versions jht@samba.org

# The following allows environment variables to override the target directories
#   the alternative is to have a file in your home directory calles .rpmmacros
#   containing the following:
#   %_topdir  /home/mylogin/redhat
#
# Note: Under this directory rpm expects to find the same directories that are under the
#   /usr/src/redhat directory
#

# RONBEE (11/22/05)
# This is a Centrify modified version taken from samba-3.0.20b
# Make sure RedHat packaging area are in place.  We don't want to
# contaminate the standard /usr/src/redhat area.
#
# NOTICE: this script now assumes environment variable CIMS_SRC is set

cdcrpmmacro=$HOME/.rpmmacros
bldtopdir="$CIMS_DEST"
if [ \! -f $cdcrpmmacro ]; then
    echo "%_topdir     $bldtopdir" > $cdcrpmmacro
fi
if [ \! -d $bldtopdir ]; then
    mkdir $bldtopdir
fi
if [ \! -d $bldtopdir/BUILD ]; then
    mkdir $bldtopdir/BUILD
fi
if [ \! -d $bldtopdir/SOURCES ]; then
    mkdir $bldtopdir/SOURCES
fi
if [ \! -d $bldtopdir/SPECS ]; then
    mkdir $bldtopdir/SPECS
fi
if [ \! -d $bldtopdir/SRPMS ]; then
    mkdir $bldtopdir/SRPMS
fi
if [ \! -d $bldtopdir/RPMS ]; then
    mkdir $bldtopdir/RPMS
fi

SPECDIR=`rpm --eval %_specdir`
SRCDIR=`rpm --eval %_sourcedir`

# At this point the SPECDIR and SRCDIR vaiables must have a value!

USERID=`id -u`
GRPID=`id -g`
SAMBANAME="CentrifyDC-samba"
VERSION='3.0.27a'
REVISION=''
SPECFILE="samba3.spec"
RPMVER=`rpm --version | awk '{print $3}'`
RPM="rpm"
echo The RPM Version on this machine is: $RPMVER

##
## fix the mandir macro
##
case $RPMVER in
    [23]*)
       sed -e "s/MANDIR_MACRO/\%\{prefix\}\/man/g" < samba.spec > $SPECFILE
       ;;
    4*)
       sed -e "s/MANDIR_MACRO/\%\{_mandir\}/g" < samba.spec > $SPECFILE
       ;;
    *)
       echo "Unknown RPM version: `rpm --version`"
       exit 1
       ;;
esac

case ${OS_REV} in
   suse8)
        sed -e 's/libacl-devel/acl-devel/g' \
        -e 's/libattr-devel/attr-devel/g' < $SPECFILE >$SPECFILE.bak
        mv $SPECFILE.bak $SPECFILE
        ;;
   rh7.2)
       #Don't build cups on rh7.2, it uses LPRng print system by default.
        sed -e '/enable-cups/d' \
        -e 's/with-smbmount \\/with-smbmount/g' \
        -e 's/cups-devel//g' \
        -e 's/libacl-devel//g' \
        -e 's/libattr-devel//g' \
        -e 's/cups//g'  < $SPECFILE >$SPECFILE.bak
        
        mv $SPECFILE.bak $SPECFILE
        ;;     
esac

##
## now catch the right command to build an RPM (defaults ro 'rpm'
##
case $RPMVER in
    4.[123]*)
       RPM="rpmbuild"
       ;;
esac

echo "RPM build command is \"$RPM\""

pushd .
cd ../../source
if [ -f Makefile ]; then
        make distclean
fi
popd

pushd .
cd ../../../
chown -R ${USERID}.${GRPID} ${SAMBANAME}-${VERSION}${REVISION}
if [ ! -d ${SAMBANAME}-${VERSION} ]; then
        ln -s samba-${VERSION}${REVISION} ${SAMBANAME}-${VERSION} || exit 1
fi
echo -n "Creating ${SAMBANAME}-${VERSION}.tar.bz2 ... "
tar --exclude=.svn -cf - ${SAMBANAME}-${VERSION}/. | bzip2 > ${SRCDIR}/${SAMBANAME}-${VERSION}.tar.bz2
echo "Done."
if [ $? -ne 0 ]; then
        echo "Build failed!"
        exit 1
fi

popd


/bin/cp -p filter-requires-samba_rh8.sh ${SRCDIR}
/bin/cp -p filter-requires-samba_rh9.sh ${SRCDIR}
chmod 755 ${SRCDIR}/filter-requires-samba_rh?.sh
/bin/cp -av $SPECFILE ${SPECDIR}

#
# Now build the RPM
#
PKG_FILE=centrifydc-$SAMBA_ORG_NAME-$CENTRIFY_VERSION_NUMBER-$CENTRIFY_BUILD_NUMBER-$OS_REV-$ARCH.rpm
RPM_OUTPUT_FILE=$CENTRIFY_SAMBA-$SAMBA_VERSION-$CENTRIFY_VERSION_NUMBER.$CENTRIFY_BUILD_NUMBER.$ARCH.rpm

if [ -f filelist.${OS_REV} ]; then
    FILELIST=filelist.${OS_REV}
else
    FILELIST=filelist.default
fi

# RONBEE: Make sure we use the right RPM tool
RPM_BB=rpmbuild
if [ "${OS_REV}" = "suse8" ] || [ "${OS_REV}" = "debian" ]; then
    # The debian version is installed rpm4.0
    RPM_BB=rpm
fi
echo Getting Ready to build rpm package: $PKG_FILE
cd ${SPECDIR}

# RONBEE (02/01/06): don't not use _rpmfilename because only debuginfo will be
# included :-(.  Rather rename the file instead.
${RPM_BB} -bb --clean --define "_topdir $bldtopdir" \
                   --define "_version ${VERSION}" \
                   --define "_release ${CENTRIFY_VERSION_NUMBER}.${CENTRIFY_BUILD_NUMBER}" \
                   --define "_install_base ${INSTALL_BASE}" \
                   --define "_lib_cpu lib" \
                   --define "_lib ${LIB_CPU}" \
                   --define "_FILELIST ${FILELIST}" \
                   --define "_VENDOR ${OS_REV}" \
                   --define "_CFG_FLAGS ${CFG_FLAGS}" \
                   --rmsource $SPECFILE
mv $CIMS_DEST/RPMS/$ARCH/$RPM_OUTPUT_FILE $CIMS_DEST/RPMS/$PKG_FILE
if [ "${OS_REV}" = "debian" ];then  
   cd $CIMS_DEST/RPMS   
   TMP_FILE=`sudo alien -k -c ${PKG_FILE} | grep generated | sed "s/ generated//"`
   rm -f $PKG_FILE
   PKG_FILE=`echo ${PKG_FILE} | sed "s/rpm/deb/" | sed "s/debian/deb3/"`
   mv -f ${TMP_FILE} ${PKG_FILE}
   cd ${OLDPWD}
fi

# RONBEE (12/01/05): remove the .rpmmacros
rm -f $cdcrpmmacro

echo Done.

