#ifndef __LIBTDB_H__
#define __LIBTDB_H__

/* 
   Unix SMB/CIFS implementation.

   trivial database library

   Copyright (C) Andrew Tridgell 1999-2004
   Copyright (C) David Daugherty 2005

     ** NOTE! The following LGPL license applies to the libtdb
     ** library. This does NOT imply that all of Samba is released
     ** under the LGPL

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
 * NOTE!!
 * This code implements thin wrappers around the LGPL'd tdb source code and
 * is used to generate libtdb.so that can be used by commercial packages.
 * Please take care NOT to include any GPL'd code here!
 *
 * Further: Do not add any definitions to this file that make other Samba
 * headers (including tdb.h) to be necessary for compilation.
 */

#include "config.h"

/***
 * SIZEOF_type is determined by configure
 ***/
#ifndef SIZEOF_SHORT
#define SIZEOF_SHORT 2
#endif
#ifndef SIZEOF_INT
#define SIZEOF_INT 4
#endif
#ifndef SIZEOF_LONG
#define SIZEOF_LONG 4
#endif

#if !defined(uint8)
# define uint8 unsigned char 
#endif

#if !defined(uint32) 
#if (SIZEOF_INT == 4)
#define uint32 unsigned int
#elif (SIZEOF_LONG == 4)
#define uint32 unsigned long
#elif (SIZEOF_SHORT == 4)
#define uint32 unsigned short
#endif
#endif

#if !defined(TRUE)
#define TRUE (1)
#endif

#if !defined(FALSE)
#define FALSE (0)
#endif

/* This does not seem to work to avoid GNU compiler warnings - too bad! */
#ifndef CONST_CAST
#define CONST_CAST(type, ptr)      ((type) ((void *) (ptr)))
#endif

/* LIBTDB Return Codes */
#define LIBTDB_SUCCESS          0           /* Success */
#define LIBTDB_OPEN_FAILED      1           /* Opening the TDB File failed */
#define LIBTDB_CLOSE_FAILED     2           /* Closing the TDB File failed */
#define LIBTDB_READ_FAILED      3           /* Reading the TDB File failed */
#define LIBTDB_WRITE_FAILED     4           /* Writing the TDB File failed */
#define LIBTDB_BUF_TOO_SMALL    5           /* The return buffer needs to be bigger */
#define LIBTDB_BAD_PARAM        6           /* Missing or bad parameter */
#define LIBTDB_NO_DATA          7           /* No data was read (bad key?) */
#define LIBTDB_TRAVERSE_FAILED  8           /* Traversing a TDB file failed */

typedef void* TDB_HANDLE;   /* Hide the definition of TDB_CONTEXT from the outside world */

typedef struct traverse_control
{
    int count;                                      /* Number of records traversed */
    TDB_HANDLE handle;                              /* The TDB handle used to traverse the file */
    char *key;                                      /* The current key (for each callback) */
    int keysize;                                    /* The current key size */
    void *data;                                     /* The current data */
    int datasize;                                   /* The current data size */
    int (*callback)(struct traverse_control *);     /* The function to call for each record */
    void *param1;                                   /* Client private data area to recover context */
    void *param2;                                   /* Client private data area to recover context */
    void *param3;                                   /* Client private data area to recover context */
    void *param4;                                   /* Client private data area to recover context */
} traverse_control;

            
#ifdef  __cplusplus
extern "C" {
#endif

int libtdb_set_machineinfo(const char *tdbfile, const char *domain, const char *password, uint32 sec_channel);

int libtdb_get_machineinfo(const char *tdbfile, const char *domain, char *password, size_t size, size_t *real_size,
                           time_t *last_set_time, uint32 *sec_channel);

int libtdb_open(const char *tdbfile, int open_flags, mode_t mode, TDB_HANDLE *tdb_handle);
int libtdb_close(TDB_HANDLE tdb_handle);
int libtdb_read(TDB_HANDLE tdb_handle, const char *key, void *data, size_t size, size_t *real_size);
int libtdb_write(TDB_HANDLE tdb_handle, const char *key, const void *data, size_t datasize);
int libtdb_traverse(const char *tdbfile, traverse_control *tctl);

                    
#ifdef  __cplusplus
}
#endif

#endif /* __LIBTDB_H__ */
